close all;
clear;
tic;

% Define frequency and AUT placement.
freq = 2100e6;
center_offset = 0.4;  % of AUT
roll_angle = 0;  % of AUT
azimuth_angle = (-180:4:179)';  % of AUT

% Fixed chamber antenna. Model of ETS Lindgren 3164-05 as a cosn-antenna with
% the 3 dB beamwidths 45 and 65 degrees in E-plane and H-plane, respectively.
% This model is valid for the frequency range 2-3 GHz.
a = gen_farfield('cosn 22.5 32.5', 41);
a.freq = freq;
efficiency_dB = -4;  % does not really matter, since we normalize with ref. ant.
a = set_power_radiated(a, 10^(efficiency_dB/10)*4*pi);
a_ver = rotate_farfield(a,  0, 90, 180);
a_hor = rotate_farfield(a, 90, 90, 180);
cbr_a = [a_ver a_hor];
cbr_p = gen_positions([3.7 3.7], 0, 1.3);

% Reference antenna.
ref_a = gen_farfield('inc. electric dipole');
ref_a.freq = freq;
ref_p = gen_positions(0, 0, 1.3);

% Antenna under test (AUT).
a = read_farfield(sprintf('../data/Bowtie_diff_exc/%.0f.txt', freq/1e6));
aut_a = [rotate_farfield(a, 0, 90, 0) rotate_farfield(a, 90, 90, 0)];

% 1. Rotate around x-axis (roll).
% 2. Rotate around z-axis (azimuth).
% => zyz-rotate: 90, roll, azimuth-90
[x, y, z] = zyzrot(0, -center_offset, 0, 90, roll_angle, azimuth_angle-90);
z = z + 1.3;
aut_p = gen_positions([x x], y, z, 90, roll_angle, azimuth_angle-90);

% Calculate coupling.
v_ref = calc_coupling(ref_a, ref_p, cbr_a, cbr_p);
H = calc_coupling(aut_a, aut_p, cbr_a, cbr_p);
H = H ./ v_ref(1);
H = H ./ sqrt(size(aut_p.x,2));
toc;

% Plot far-fields in chamber.
hf = figure;
plot_farfield_inpos(cbr_a, cbr_p, 1, 1, 0.2);
plot_farfield_inpos(ref_a, ref_p, 1, 1, 0.2);
plot_farfield_inpos(aut_a, aut_p, 1, find(azimuth_angle==0), 0.2);
plot_chamber('Chalmers AC');

% Plot result.
figure; plot_cdf(H);
figure; plot_pod(H);
figure; plot_pod(mimo_svd(H));
figure; plot_pod(mimo_zf(H));
figure; plot_pod(diversity_mrc(H));
