close all;
clear;
tic;
freq = 2.7e9;

% Fixed chamber antenna array (transmitting).
a = gen_farfield('inc. Huygens source');
a.freq = freq;
a1 = rotate_farfield(a,  0, 90, 0);
a2 = rotate_farfield(a, 90, 90, 0);
cbr_a = [a1 a2];
cbr_p = gen_positions(-7, 0, [1 1]);

% Antenna under test (receiving).
pth = '../data/Laird/';
a1 = read_farfield([pth 'top_antenna_single_hand.txt']);
a1 = interp_freq_farfield(a1, freq);
a1 = rotate_farfield(a1, 90, 90, 0);
a1 = set_power_radiated(a1);
a2 = read_farfield([pth 'top_antenna_freespace.txt']);
a2 = interp_freq_farfield(a2, freq);
a2 = rotate_farfield(a2, 0, 90, 0);
a2 = set_power_radiated(a2);
aut_a = [a1 a2];
figure;
plot_farfield(a1);
%save_png('meas_pattern1.png', 32, [], 150);
%modify_image('meas_pattern1.png');
figure;
plot_farfield(a2);
%save_png('meas_pattern2.png', 32, [], 150);
%modify_image('meas_pattern2.png');

% Reference antenna.
ref_a = gen_farfield('inc. electric dipole');
ref_a.freq = freq;
ref_p = gen_positions(0);

% Antenna under test (AUT) on turn-table.
tt_angle = (-180:179)';

% Calculate coupling.
v_ref = calc_coupling(ref_a, ref_p, cbr_a, cbr_p);
assert(abs(v_ref(1))>1e3*abs(v_ref(2)), 'Wrong polarization reference.');

% Position of AUT on platform.
figure;
rho_vector = 0:1:2;
for irho = 1:numel(rho_vector)
    rho = rho_vector(irho);

    % Antenna under test (AUT) on turn-table.
    [x, y, z] = zyzrot(rho, 0, 1, repmat(tt_angle,1,2), 0, 0);
    aut_p = gen_positions(x, y, z, tt_angle, 0, 0);

    % Calculate coupling.
    H = calc_coupling(aut_a, aut_p, cbr_a, cbr_p) / v_ref(1);
    plot_pod(mimo_svd(H));
end
title('PoD - SVD');

toc;

% Plot antennas in geometry.
figure;
plot_farfield_inpos(cbr_a, cbr_p);
plot_farfield_inpos(aut_a, aut_p);

% Plot result.
figure;
plot_cdf(mimo_svd(H));
plot_cdf(mimo_zf(H));
plot_cdf(diversity_mrc(H));
plot_cdf(diversity_max(H));

figure;
plot_pod(mimo_svd(H));
plot_pod(mimo_zf(H));
plot_pod(diversity_mrc(H));
plot_pod(diversity_max(H));
