close all;
clear;

% Define example far-field.
%a1 = read_farfield('../data/CST/Ch_Monopole_1_5.9.txt');
a1 = gen_farfield('cosn 30');
a1.freq = -1;
a1 = rotate_farfield(a1, 45, -135, 0);
a2 = mirror_farfield(a1);

% Define position and orientation.
x = 22; y = 43; z = 1;
alpha = 45;
theta = 20;
phi = 125;

% Calculate resulting far-field in xy-plane. Assert that the tangential E-field
% is zero.
[Eth1, Eph1] = get_farfield(a1, alpha,  theta, phi, 90, 0:360);
[Eth2, Eph2] = get_farfield(a2, alpha, -theta, phi, 90, 0:360);
E_tangential = max(abs(Eph1+Eph2));
E_orthogonal = max(abs(Eth1+Eth2));
assert(E_tangential<1e-5, 'Tangential field not zero!');
E_tangential %#ok<NOPTS>
E_orthogonal %#ok<NOPTS>

% Define cases and plot fields.
p1 = gen_positions(x, y, z, alpha, theta, phi);
p2 = gen_positions(x, y, -z, alpha, -theta, phi);  % z and theta change sign!
figure;
plot_farfield_inpos(a1, p1);
plot_farfield_inpos(a2, p2);
plot3([x x], [y y], [-z z], 'k-');
g = -2:0.5:2;
xx = [g;g];
yy = repmat([-2;2], 1, numel(g));
zz = zeros(size(xx));
plot3(x+xx, y+yy, zz, 'k-');
plot3(x+yy, y+xx, zz, 'k-');
axis image;
