close all;
clear;

% Define an antenna element pattern.
a_el = gen_farfield('cosn 50 70', 41, 81);
a_el.freq = 60e9;
lambda = 3e8 ./ a_el.freq;

% Plot the antenna element pattern in 3D.
figure;
plot_farfield(a_el);

% Make an array of antenna patterns.
d = 0.4*lambda;
[a, p] = make_array(a_el, 1*d, 3*d, d, d, 0, 0, 0, 0, 90, 0);

% Plot the antenna array in 3D. (One element pattern and dots for each
% antenna element position.)
figure;
plot_farfield_inpos(a, p);
view(-40, 30);

% Define amplitude and phase excitation of array so that we get the array to
% radiate in the direction given by aa_theta and aa_phi.
aa_theta = 90;
aa_phi = 30;
[x, y, z] = rthetaphi2xyz(1, aa_theta, aa_phi);
v_exc = exp(-2j*pi*(x*p.x+y*p.y+z*p.z)/lambda);

% Calculate far-field from antenna array by adding the radiation from each
% antenna element in the array excited by the complex voltage v_exc.
a_array = a;
a_array.Eth = zeros(size(a.Eth));
a_array.Eph = zeros(size(a.Eph));
for ipos = 1:p.N
    a2 = translate_farfield(a, p.x(ipos,1), p.y(ipos,1), p.z(ipos,1));
    a_array.Eth = a_array.Eth + v_exc(ipos,1) .* a2.Eth;
    a_array.Eph = a_array.Eph + v_exc(ipos,1) .* a2.Eph;
end
figure;
plot_farfield(a_array, [], [], d/2, 30);
plot3(p.x, p.y, p.z, 'k.');
