close all;
clear;
tic;

% Physical tilt of array. (For electrical tilt, use weighting of the calculated
% H-matrix in dimension 4.)

freq = 2e9;
center_offset = 0.1;
tilt_angle = 10;

% Fixed chamber antenna array (transmitting).
a = gen_farfield('inc. Huygens source');
a.freq = freq;
a1 = rotate_farfield(a,  45, 0, 0);
a2 = rotate_farfield(a, -45, 0, 0);
Dx = 1;
Dy = 4;
max_dl = 0.9*3e8/freq;
[cbr_a,cbr_p] = make_array([a1 a2], Dx, Dy, max_dl, max_dl, ...
    -7, 0, 1, 0, 90+tilt_angle, 0);

% Reference antenna.
ref_a = gen_farfield('inc. electric dipole');
ref_a.freq = freq;
ref_p = gen_positions(0, 0, 1);

% Antenna under test (AUT) on turn-table.
aut_a = [gen_farfield('inc. electric dipole') ...
         gen_farfield('inc. magnetic dipole')];
%aut_a = gen_farfield('inc. Huygens source');
aut_a(1).freq = freq;
aut_a(2).freq = freq;
tt_angle = (-180:179)';
[x, y, z] = zyzrot(center_offset, 0, 1, tt_angle, 0, 0);
aut_p = gen_positions([x x], y, z, tt_angle, 0, 0);

% Calculate coupling.
v_ref = sum(calc_coupling(ref_a, ref_p, cbr_a, cbr_p), 4);
H = sum(calc_coupling(aut_a, aut_p, cbr_a, cbr_p), 4);
H = H ./ repmat(v_ref, [size(aut_p.x,2) 1 numel(tt_angle)]);
H = H ./ sqrt(size(aut_p.x,2));

toc;

figure;
plot_farfield_inpos(cbr_a, cbr_p, [], [], max_dl);
plot_farfield_inpos(ref_a, ref_p, [], [], max_dl);
plot_farfield_inpos(aut_a, aut_p, [], [], max_dl);

% Plot result.
figure;
plot_pod(mimo_svd(H));
plot_pod(mimo_zf(H));
plot_pod(diversity_mrc(H));
