close all;
clear;
tic;
freq = 3e9;

% Fixed chamber antenna array (transmitting).
a = gen_farfield('inc. Huygens source');
a.freq = freq;
a1 = rotate_farfield(a,  0, 90, 0);
a2 = rotate_farfield(a, 90, 90, 0);
cbr_a = [a1 a2];
cbr_p = gen_positions(-7, 0, [1 1], 0, 0, 0);

% Antenna under test (receiving).
a = gen_farfield('inc. Huygens source');
a.freq = freq;
a1 = rotate_farfield(a, -22.5   , 90, 0);
a2 = rotate_farfield(a, -22.5+90, 90, 0);
aut_a = [a1 a2 a1 a2];

% Reference antenna.
ref_a = gen_farfield('inc. electric dipole');
ref_a.freq = freq;
ref_p = gen_positions(0, 0, 0, 0, 0, 0);

% Antenna under test (AUT) on turn-table.
tt_angle = (-180:179)';
n = numel(tt_angle);
[x, y, z] = zyzrot(ones(n,4), repmat([-1.5 -0.5 0.5 1.5],n,1), 1, ...
    repmat(tt_angle,1,4), 0, 0);
aut_p = gen_positions(x, y, z, tt_angle, 0, 0);

% Calculate coupling.
v_ref = calc_coupling(ref_a, ref_p, cbr_a, cbr_p);
assert(abs(v_ref(1))>1e3*abs(v_ref(2)), 'Wrong polarization reference.');
H = calc_coupling(aut_a, aut_p, cbr_a, cbr_p) / v_ref(1);

toc;

% Plot antennas in geometry.
figure;
plot_farfield_inpos(cbr_a, cbr_p);
plot_farfield_inpos(aut_a, aut_p);

figure;
h1 = plot_cdf(mimo_svd(H));
h2 = plot_cdf(mimo_zf(H));
h3 = plot_cdf(diversity_mrc(H));
h4 = plot_cdf(diversity_max(H));

figure;
h1 = plot_pod(mimo_svd(H));
h2 = plot_pod(mimo_zf(H));
h3 = plot_pod(diversity_mrc(H));
h4 = plot_pod(diversity_max(H));
