close all;
clear;

% Fixed chamber antenna.
cbr_a = gen_farfield('inc. electric dipole');
cbr_a.freq = 2.4e9;
cbr_p = gen_positions(4, 0, 1);

% Antenna under test (AUT) on turn-table.
tmp = linspace(0, 360, 65);
tt_angle = tmp(1:end-1)';
h = 1;
aut_a = gen_farfield('inc. Huygens source');
aut_a.freq = cbr_a.freq;
aut_a = rotate_farfield(aut_a, 0, -90, 0);

lgnd{1} = 'Reference';
rho_vector = 0:0.5:2.0;
for ii = 1:numel(rho_vector)

    % Antenna under test (AUT) on turn-table.
    [x, y, z] = zyzrot(rho_vector(ii), 0, h, tt_angle, 0, 0);
    aut_p = gen_positions(x, y, z, tt_angle, 0, 0);

    v = calc_coupling(aut_a, aut_p, cbr_a, cbr_p);
    v = v ./ ((3e8/aut_a.freq) ./ (4*pi*abs(cbr_p.x)));
    v = v ./ max(hypot(cbr_a.Eth(:), cbr_a.Eph(:)));
    P_dB(:,ii) = 20*log10(abs(v(:))); %#ok<SAGROW>
    lgnd{ii+1} = sprintf('\\rho = %.2f m', rho_vector(ii)); %#ok<SAGROW>
end
P_dB(P_dB<-50) = -50;

% Plot fixed platform location.
figure;
plot_platform();
plot3(aut_p.x, aut_p.y, aut_p.z, 'k.');
plot3(cbr_p.x, cbr_p.y, cbr_p.z, 'ko');
for ii = 1:8:numel(tt_angle)
    plot_farfield_inpos(aut_a, aut_p, [], ii);
end

indx = find(aut_a.theta==90);  % azimuth plane
P_ref_dB = 20*log10(hypot(aut_a.Eth(indx,:), aut_a.Eph(indx,:)));
P_ref_dB(P_ref_dB<-50) = -50;

figure;
plot(aut_a.phi, P_ref_dB, 'k-', 'Linewidth', 2); hold on;
plot(tt_angle, P_dB);
grid on;
axis([0 360 -40 10]);
set(gca, 'XTick', 0:45:360);
xlabel('Phi [deg]');
ylabel('Gain [dBi]');
legend(lgnd, 'Location', 'southwest');

cdf = (1:size(P_dB,1)) / size(P_dB,1);
cdf_ref = (1:numel(P_ref_dB)) / numel(P_ref_dB);

figure;
plot(sort(P_ref_dB), 100*cdf_ref, 'k-', 'Linewidth', 2); hold on;
plot(sort(P_dB,1), 100*cdf);
grid on;
axis([-40 10 0 100]);
xlabel('Gain [dBi]');
ylabel('CDF [%]');
legend(lgnd, 'Location', 'northwest');

