close all;
clear;

% Define vertical and horizontal dipoles.
a_ver = gen_farfield('inc. electric dipole');
a_hor = rotate_farfield(a_ver, 0, 90, 90);
a_ver_mirror = mirror_farfield(a_ver);
a_hor_mirror = mirror_farfield(a_hor);

% Define positions.
h_tx = 10;
h_rx = h_tx;
p1 = gen_positions(0, 0, h_tx);
p2 = gen_positions(0, 0, -h_tx);
d = logspace(0, 5, 1000)';
p = gen_positions(d, 0, h_rx);

% Calculate coupling (sum of TX antenna and mirror of TX antenna).
H_ref = calc_coupling(a_ver, p, a_ver, p1);
H_ver = calc_coupling(a_ver, p, a_ver, p1) + ...
    calc_coupling(a_ver, p, a_ver_mirror, p2);
H_hor = calc_coupling(a_hor, p, a_hor, p1) + ...
    calc_coupling(a_hor, p, a_hor_mirror, p2);
H_ref_dB = 20*log10(abs(H_ref(:)));
H_ver_dB = 20*log10(abs(H_ver(:)));
H_hor_dB = 20*log10(abs(H_hor(:)));

% Plot result.
figure;
semilogx(d, H_ref_dB);
hold on;
semilogx(d, H_ver_dB);
semilogx(d, H_hor_dB);
grid on;
xlabel('Distance [\lambda]');
ylabel('Coupling [dB]');
legend('One ray', 'Two-ray, vertical dipole', 'Two-ray, horizontal dipole');
title('Two-ray coupling');
save_png('two_ray.png');
