function [adg1,adg2,adg3] = adg_algorithms(H)
%ADG_ALGORITHMS Calculates apparent diversity gain (three alternative formulas)
%
%   function [adg1,adg2,adg3] = adg_algorithms(H)
%
%   Calculates apparent diversity gain with three alternative formulas. Number
%   of rx antennas must be two, and number of tx antennas must be one.

% By Ulf Carlberg.

assert(size(H,1)==2, 'Channel matrix must have two receive antennas.');
assert(size(H,2)==1, 'Channel matrix must have one transmit antenna.');

% Mean Effective Directivity (MED).
med = mean(abs(H(:,:)).^2, 2);

% Efficiency Ratio.
e_ratio = min(med) / max(med);

% Correlation.
tmp = corrcoef(H(:,:).');
correlation = tmp(1,2);

% Apparent Diversity Gain (three alternative formulas).
rho2 = abs(correlation)^2;
adg1 = 10.48*sqrt(1 - rho2);
adg2 = 10.48*sqrt(1 - 0.99*rho2);
adg3 = sqrt(1+(10.48^2-1) * e_ratio * (1-rho2));
    
end
