function [xx, yy] = gen_grid(grid_type, d, nrows, ncols)
%GEN_GRID Generates a 2D grid of points.
%
%   function [xx, yy] = gen_grid(grid_type, d, nrows, ncols)
%
%   grid_type - 'rectangular' or 'circular'
%   d         - distance between grid points
%   nrows     - number of rows
%   ncols     - number of columns (default = number of rows)

% By Ulf Carlberg.

if nargin<4 || isempty(ncols), ncols = nrows; end

% Generate a rectangular grid.
x = linspace(-d*(nrows-1)/2, d*(nrows-1)/2, nrows);
y = linspace(-d*(ncols-1)/2, d*(ncols-1)/2, ncols);
[xx, yy] = meshgrid(x, y);

if strcmpi(grid_type, 'rectangular')
    % Do nothing, we are done!
elseif strcmpi(grid_type, 'circular')    
    % Apply circular "mask".
    assert(nrows==ncols, ...
        'Number of columns must equal number of rows for a circular grid.');
    r = d*(nrows-1)/2;
    xx(hypot(xx, yy)>r) = NaN;
    yy(hypot(xx, yy)>r) = NaN;
else
    error('Unknown grid type.');
end
