function bw = get_beamwidth(theta, G_dB, level_dB)
%GET_BEAMWIDTH Get beamwidth from maximum radiation direction.
%
%   function bw = get_beamwidth(theta, G_dB, level_dB)
%
%   Get beamwidth "bw" in degrees from gain curve "theta" and "G_dB" at
%   level "level_dB" (default 3). The beamwidth is calculated from maximum of
%   "G_dB".

% By Ulf Carlberg.

% Default 3 dB beamwidth.
if nargin<3, level_dB = 10*log10(2); end

% Check input.
assert(level_dB>0, 'The input "level_dB" should be positive.');

% Calculate beamwidth from maximum of G_dB.
[G_max_dB, imax] = max(G_dB);
theta_max = theta(imax);
theta_x = zero_crossings(theta, G_dB-G_max_dB+level_dB);
theta1 = max(theta_x(theta_x<theta_max));
theta2 = min(theta_x(theta_x>theta_max));
bw = theta2 - theta1;

% If we can't find a well-defined beamwidth, return NaN or 360.
if isempty(bw)
    if abs(theta(end)-theta(1)) == 360
        bw = 360;
    else
        bw = NaN;
    end
end

end
