function G_dB = get_gain(a, theta, phi, freq)
%GET_GAIN Get gain from antenna structure far-field.
%
%   function G_dB = get_gain(a, theta, phi, freq)
%
%   Get gain in decibel [dB] from far-field in directions "theta" and "phi", at
%   frequencies "freq". (The last three arguments are optional, and the default
%   directions and frequencies are taken from the antenna structure definition.)

% By Ulf Carlberg.

if nargin<2, theta = []; end
if nargin<3, phi = []; end
if nargin<4, freq = []; end

[Eth, Eph] = get_farfield_components(a, theta, phi, freq);
G_dB = 10*log10( abs(Eth).^2 + abs(Eph).^2 );

end
