function [G_dB, theta, phi] = get_max_gain(a)
%GET_MAX_GAIN Get maximum gain and direction from antenna structure far-field.
%
%   function [G_dB, theta, phi] = get_max_gain(a)
%
%   Get maximum gain in decibel [dB] from far-field. Also return the angular
%   direction where the antenna radiates maximum power.

% By Ulf Carlberg.

% Init output.
G_dB = zeros(a.Nfreq, 1);
theta = zeros(a.Nfreq, 1);
phi = zeros(a.Nfreq, 1);

% Get data.
G_mat_dB = get_gain(a);
for ifreq = 1:a.Nfreq
    tmp = G_mat_dB(:, :, ifreq);
    [~, indx] = max(tmp(:));
    itheta = mod(indx, a.Nth);
    iphi = ceil(indx / a.Nth);
    G_dB(ifreq) = G_mat_dB(itheta, iphi, ifreq);
    theta(ifreq) = a.theta(itheta);
    phi(ifreq) = a.phi(iphi);
end

end
