function XPD_dB = get_xpd(a, co_hat, theta, phi, freq)
%GET_XPD Get cross-polar decoupling (XPD) from antenna structure far-field.
%
%   function XPD_dB = get_xpd(a, co_hat, theta, phi, freq)
%
%   Get cross-polar decoupling (XPD) in decibel [dB] from far-field "a" in
%   directions "theta" and "phi" for polarization "co_hat" (2-vector with theta 
%   and phi components) and frequencies "freq".

% By Ulf Carlberg.

if nargin<3, theta = []; end
if nargin<4, phi = []; end
if nargin<5, freq = []; end

% Normalize co-polarization vector and define cross-polarization vector.
assert(numel(co_hat)==2, 'Polarization vector have wrong size.');
co_hat = co_hat / norm(co_hat);
xp_hat = conj([co_hat(2) -co_hat(1)]);

% Get components.
[Eth, Eph] = get_farfield_components(a, theta, phi, freq);

% Calculate XPD.
Eco = Eth*conj(co_hat(1)) + Eph*conj(co_hat(2));
Exp = Eth*conj(xp_hat(1)) + Eph*conj(xp_hat(2));
XPD_dB = 20*log10(abs(Eco./Exp));

% Limit values to 300 dB because "Inf" can mess up plots.
XPD_dB = min(XPD_dB, 300);
XPD_dB = max(XPD_dB, -300);

end
