function P = integrate_farfield(a)
%INTEGRATE_FARFIELD Power integration of antenna far-field structure.
%
%   function P = integrate_farfield(a))
%
%   Integrates the far-field function of antenna structure "a" to get the total
%   radiated power. The radiation efficiency is 100% if P = 4*pi.

% By Ulf Carlberg.

% Integrate power density.
Wth = (abs(a.Eth).^2 + abs(a.Eph).^2) .* sind(a.theta);
P = trapz(a.phi.', trapz(a.theta, Wth, 1), 2);
P = (pi/180)^2 * P(:);

end
