function a = interp_freq_farfield(a, freq)
%INTERP_FREQ_FARFIELD Interpolates to a specific frequency from antenna structure.
%
%   function a = interp_freq_farfield(a, freq)
%
%   Interpolate to frequency "freq" from antenna structure "a".

% By Ulf Carlberg.

% Frequency tolerance.
freq_tol = 1;

% Simple?
[freq_delta, ifreq] = min(abs(a.freq-freq));
if freq_delta <= freq_tol
    a = select_freq_farfield(a, ifreq);
    return
end

% Check antenna structure and input. Require monotonically increasing
% frequencies in antenna structure.
assert(all(diff(a.freq)>0), ['Frequencies must be monotonically increasing ' ...
    'in antenna structure.']);
assert(freq >= a.freq(1)-freq_tol && freq <= a.freq(end)+freq_tol, ...
    'Selected frequency is not defined in antenna structure.');

% Leave tag on structure.
a.actions{end+1,1} = ['interp_freq_farfield(*, ' function_call_str({freq}) ...
    ')'];

% Find index to frequencies that we use in interpolation.
i1 = find(a.freq<=freq+freq_tol, 1, 'last');
i2 = find(a.freq>=freq-freq_tol, 1, 'first');

% Calculate weights of from these frequencies.
df = a.freq(i2) - a.freq(i1);
w1 = (a.freq(i2)-freq) / df;
w2 = 1 - w1;

% Update antenna structure by interpolation.
a1 = select_freq_farfield(a, i1);
a2 = select_freq_farfield(a, i2);
a.Nfreq = 1;
a.freq = freq;
a.Eth = w1*a1.Eth + w2*a2.Eth;
a.Eph = w1*a1.Eph + w2*a2.Eph;

end
