function a = limit_farfield(a, angle_sector, power_radiated)
%LIMIT_FARFIELD Make far-field zero outside angle sector.
%
%   function a = limit_farfield(a, angle_sector, power_radiated)
%
%   Make far-field of antenna "a" zero outside "angle_sector", which should be
%   [theta_min theta_max phi_min phi_max] in degrees. Set power radiated to
%   "power_radiated". This is optional and default is an empty matrix which will
%   not change the gain of the antenna.

% By Ulf Carlberg.

if nargin<3, power_radiated = []; end

% Leave tag on structure.
a.actions{end+1,1} = ['limit_farfield(*, ' ...
    function_call_str({angle_sector}) ')'];

% Find index.
tmp = mod(angle_sector, 360);
tmp(angle_sector==360) = 360;
indx_th = a.theta<tmp(1) | a.theta>tmp(2);
if angle_sector(3) >= 0
    indx_ph = a.phi<tmp(3) | a.phi>tmp(4);
else
    indx_ph = a.phi<tmp(3) & a.phi>tmp(4);    
end
a_min = 10^(-200/20);    

% Update antenna structure.
a.Eth(indx_th,:,:) = a_min;
a.Eph(indx_th,:,:) = a_min;
a.Eth(:,indx_ph,:) = a_min;
a.Eph(:,indx_ph,:) = a_min;

% Set power radioated.
if ~isempty(power_radiated)
    a = set_power_radiated(a, power_radiated);
end

end
