function [a, p] = make_array(a, Dx, Dy, max_dx, max_dy, x, y, z, alpha, theta, phi)
%MAKE_ARRAY Construct an antenna array.
%
%   function [a, p] = make_array(a, Dx, Dy, max_dx, max_dy, x, y, z, ...
%       alpha, theta, phi)
%
%   Duplicate antenna elements "a" to an array. First, the array is constructed
%   in the xy-plane with dimentions "Dx" [m] and "Dy" [m] and maximum element
%   distance of "max_dx" [m] and "max_dy" [m]. Then the position of the center
%   of the array is defined by "x", "y", and "z". The orientation is defined by
%   the zyz-rotation angles "alpha", "theta", and "phi".

% By Ulf Carlberg.

% Antennas.
for iant = 1:numel(a)
    a(iant) = rotate_farfield(a(iant), alpha, theta, phi);
end

% Create antenna array in xy-plane.
array_x = linspace(-Dx/2, Dx/2, ceil(Dx/max_dx)+1);
array_y = linspace(-Dy/2, Dy/2, ceil(Dy/max_dy)+1);
[xx,yy,zz] = ndgrid(array_x, array_y, 0);

% Rotate and translate positions.
[xx_rot, yy_rot, zz_rot] = zyzrot(xx(:), yy(:), zz(:), alpha, theta, phi);
xx_rot = repmat(xx_rot, 1, numel(a));
p = gen_positions(x+xx_rot, y+yy_rot, z+zz_rot);

end
