function A = mimo_zf(H)
%MIMO_ZF MIMO algorithm of channel matrix using ZF (zero forcing).
%
%   function A = mimo_zf(H)
%
%   The channel matrix "H" have dimensions [Nrx Ntx ...]. If Nrx>=Ntx, the
%   function return a matrix "A" with dimensions [min(Nrx,Ntx) ...]. The
%   returned matrix contains amplitude values. (If Ntx > Nrx, an empty matrix is
%   returned.)
%
%   See also MIMO_IPSVD, MIMO_MSVD, MIMO_MZF, MIMO_SVD.

% By Ulf Carlberg.

% Init output.
siz = [size(H) 1];
if siz(1) < siz(2)
    Nzf = 0;
else
    Nzf = min(siz(1:2));
end
A = zeros([Nzf siz(3:end)]);

% Calculate.
if Nzf > 0
    w = warning;
    warning('off', 'MATLAB:singularMatrix');  % ok, because we invert twice
    warning('off', 'MATLAB:nearlySingularMatrix');
    for ii = 1:prod(siz(3:end))
        HH = H(:,:,ii)' * H(:,:,ii);
        invHH = eye(Nzf) / HH;
        if ~any(isnan(HH))  % if HH contain NaN, we should return NaN
            invHH(isnan(invHH)) = Inf;  % becomes zero on next line
        end
        A(:,ii) = sqrt(abs(real(1 ./ diag(invHH))));
    end
    warning(w);  % restore warnings
end

end
