function plot_axes_and_rings(r_unit, xyz_trans)
%PLOT_AXES_AND_RINGS Plot axes and rings in different colors.
%
%   function plot_axes_and_rings(r_unit, xyz_trans)
%
%   Plot axes and rings in different colors with radius unit "r_unit" and
%   center point in "xyz_trans" (default [0 0 0]).

% By Ulf Carlberg.

if nargin<2, xyz_trans = [0 0 0]; end

% Same some typing later...
assert(numel(xyz_trans)==3, 'xyz_trans is wrong.');
x = xyz_trans(1);
y = xyz_trans(2);
z = xyz_trans(3);

% Plot x-, y-, and z-axes.
rr = 1.2*r_unit;
ra = 1.8*r_unit;
rb = 1.9*r_unit;
hold on;
plot3([x-rr x+ra], [y y], [z z], 'r-', 'LineWidth', 2);
plot3([x x], [y-rr y+ra], [z z], 'g-', 'LineWidth', 2);
plot3([x x], [y y], [z-rr z+ra], 'b-', 'LineWidth', 2);
text(x+rb, y, z, 'x', 'Color', 'r', 'FontSize', 12);
text(x, y+rb, z, 'y', 'Color', 'g', 'FontSize', 12);
text(x, y, z+rb, 'z', 'Color', 'b', 'FontSize', 12);

% Plot the rings.
phi = 0:5:360;
a0 = zeros(size(phi));
a1 = rr*cosd(phi);
a2 = rr*sind(phi);
plot3(x+a0, y+a1, z+a2, 'r-', 'LineWidth', 2);
plot3(x+a2, y+a0, z+a1, 'g-', 'LineWidth', 2);
plot3(x+a1, y+a2, z+a0, 'b-', 'LineWidth', 2);
axis image;

end
