function h = plot_cdf(H, dim, line_spec)
%PLOT_CDF Plot CDF (cumulative distribution function).
%
%   function h = plot_cdf(H, dim, plot_style)
%
%   Plot CDF (cumulative disttribution function) curves from amplitude data in
%   "H" along dimension "dim" (default dimension maximum number of elements in
%   "H") using "line_spec" (default ''). The CDF is generated from dimension
%   "dim" of the amplitude data.
%
%   See also PLOT_POD.

% By Ulf Carlberg.

if nargin<2 || isempty(dim), [~,dim] = max(size(H)); end
if nargin<3, line_spec = ''; end

P_dB = sort(20*log10(abs(H)), dim);
CDF = (1:size(H,dim))' / size(H,dim);

P_dB = shiftdim(P_dB, dim-1);

h = semilogy(P_dB(:,:), CDF, line_spec);
hold on;
grid on;
ylim([1e-3 1e0]);
title('CDF - Cumulative Distribution Function');
xlabel('P [dB]');
ylabel('Cumulative Distribution [-]');

end
