function plot_chamber(chamber_str)
%PLOT_CHAMBER Plot different antenna measurement chambers
%
%   function plot_chamber(chamber_str)
%
%   Here is a list of att chambers defined:
%
%   "Chalmers AC" - Anechoic chamber at Chalmers antenna group.

% By Ulf Carlberg.

if strcmpi(chamber_str, 'Chalmers AC')
    box_coord = [-1.3 -1.5 0 ; 4.5 1.5 2.4];
    plot_box(box_coord);
    plot3([0   0  ], [0 0], [0 1.3], 'k-');
    plot3([3.7 3.7], [0 0], [0 1.3], 'k-');
elseif strcmpi(chamber_str, 'SP Semi-AC')
    box_coord = [-5 -6 0 ; 13 6 8];  % TODO: check these values
    plot_box(box_coord);
    phi = 0:360;
    plot3(3.5*cosd(phi), 3.5*sind(phi), zeros(size(phi)), 'k-');
    plot3(0, 0, 0, 'k.');
else
    error('Unknown chamber.'); 
end
box_coord = box_coord + 0.1*[-1;1]*[1 1 1];
axis(box_coord(:));
view(0, 45);

end

%-------------------------------------------------------------------------------

function plot_box(xyz)
for i1 = 1:2
    for i2 = 1:2
        plot3(xyz(:,1), xyz([i1 i1],2), xyz([i2 i2],3), 'b-'); hold on;
        plot3(xyz([i1 i1],1), xyz(:,2), xyz([i2 i2],3), 'b-');
        plot3(xyz([i1 i1],1), xyz([i2 i2],2), xyz(:,3), 'b-');
    end
end
end
