function h = plot_efficiency(a, plot_format, unit)
%PLOT_EFFICIENCY Plot efficiency as a function of frequency.
%
%   h = plot_efficiency(a, plot_format)
%
%   Plot efficiency of antenna structure "a" as a function of frequencies using
%   "plot_format". Return the handle "h" for the plot.

% By Ulf Carlberg.

if nargin<2, plot_format = 'b-'; end
if nargin<3, unit = 'MHz'; end

% Unit.
ii = find(strcmp(unit, {'Hz' 'kHz' 'MHz' 'GHz'}));
assert(ii>0, 'Unknown unit');
f = 10^(3*(ii-1));

h = plot(a.freq/f, 10*log10(get_power_radiated(a)), plot_format);
hold on;
ylim([-10 0]);
grid on;
title('Radiation Efficiency');
xlabel(['Frequency [' unit ']']);
ylabel('Efficiency [dB]');

end
