function plot_farfield_inpos(a, p, ifreq, ipos, r, range_dB, max_dB, pol)
%PLOT_FARFIELD_INPOS Plot far-field ("radiation pattern") of antenna in a translated position.
%
%   function plot_farfield_inpos(a, p, ifreq, ipos, r, range_dB, max_dB, pol)
%
%   Plot radiation pattern of antennas "a" in position "p" for frequency "ifreq"
%   (default 1) in position "ipos" (default 1).
%
%   See also PLOT_FARFIELD and PLOT_FARFIELD_2D.

% By Ulf Carlberg.

% Define optional input arguments if needed.
if nargin<3 || isempty(ifreq), ifreq = 1; end
if nargin<4 || isempty(ipos), ipos = 1; end
if nargin<5, r = []; end
if nargin<6, range_dB = []; end
if nargin<7, max_dB = []; end
if nargin<8, pol = ''; end
with_rings = 0;

% Plot far-field for each position.
hold on;
for iant = 1:numel(a)
    arot = rotate_farfield(a(iant), p.alpha(ipos,iant), p.theta(ipos,iant), ...
        p.phi(ipos,iant));
    xyz = [p.x(ipos,iant), p.y(ipos,iant), p.z(ipos,iant)];
    plot_farfield(arot, ifreq, xyz, r, range_dB, max_dB, pol, with_rings);
end
plot3(p.x, p.y, p.z, 'k.');
axis image;

end
