function h = plot_farfield_phicut(a, ifreq, range_dB, normalize, phi, pstyle)
%PLOT_FARFIELD_PHICUT Two-dimensional rectangular plot of the far-field.
%
%   function h = plot_farfield_phicut(a, ifreq, range_dB, normalize, phi, pstyle)
%
%   Plot far-field function of antenna defined in antenna structure "a".

% By Ulf Carlberg.

% Define optional input arguments if needed.
if nargin<2 || isempty(ifreq), ifreq = 1; end
if nargin<3 || isempty(range_dB), range_dB = 30; end
if nargin<4 || isempty(normalize), normalize = true; end
if nargin<5 || isempty(phi), phi = 0; end
if nargin<6 || isempty(pstyle), pstyle = ''; end

theta = (-180:0.25:180)';
k = find(theta>=0, 1, 'first');

phi1 = mod(phi-180, 360);
Eth_cut1 = -interp2(a.phi, a.theta, a.Eth(:,:,ifreq), phi1, -theta(1:k-1), ...
    'linear', NaN);
Eph_cut1 = -interp2(a.phi, a.theta, a.Eph(:,:,ifreq), phi1, -theta(1:k-1), ...
    'linear', NaN);
Eth_cut2 = interp2(a.phi, a.theta, a.Eth(:,:,ifreq), phi, theta(k:end), ...
    'linear', NaN);
Eph_cut2 = interp2(a.phi, a.theta, a.Eph(:,:,ifreq), phi, theta(k:end), ...
    'linear', NaN);

W_dB = 20*log10(hypot([Eth_cut1 ; Eth_cut2], [Eph_cut1 ; Eph_cut2]));
if normalize
    W_dB = W_dB - max(W_dB(:));
end
max_dB = ceil(max(W_dB(:))/10)*10;
min_dB = max_dB - range_dB;

h = plot(theta, W_dB, pstyle, 'LineWidth', 1);
hold on;
xlim([theta(1) theta(end)]);
ylim([min_dB max_dB]);
set(gca, 'XTick', theta(1):45:theta(end));
grid on;
title(sprintf('\\phi-angle = %.0f deg', phi));
xlabel('\theta-angle [deg]');
if normalize
    ylabel('Relative gain [dB]');
else
    ylabel('Realized gain [dBi]');
end

end
