function h = plot_farfield_thetacut(a, ifreq, range_dB, normalize, theta)
%PLOT_FARFIELD_THETACUT Two-dimensional rectangular plot of the far-field.
%
%   function h = plot_farfield_thetacut(a, ifreq, range_dB, normalize, theta)
%
%   Plot far-field function of antenna defined in antenna structure "a".

% By Ulf Carlberg.

% Define optional input arguments if needed.
if nargin<2 || isempty(ifreq), ifreq = 1; end
if nargin<3 || isempty(range_dB), range_dB = 30; end
if nargin<4 || isempty(normalize), normalize = true; end
if nargin<5 || isempty(theta), theta = 90; end

phi = (-180:0.25:180)';

ph = mod(phi, 360);
Eth_cut = interp2(a.phi, a.theta, a.Eth(:,:,ifreq), ph, theta, ...
    'linear', NaN);
Eph_cut = interp2(a.phi, a.theta, a.Eph(:,:,ifreq), ph, theta, ...
    'linear', NaN);

W_dB = 20*log10(hypot(Eth_cut, Eph_cut));
if normalize
    W_dB = W_dB - max(W_dB(:));
end
max_dB = ceil(max(W_dB(:))/10)*10;
min_dB = max_dB - range_dB;

h = plot(phi, W_dB, 'LineWidth', 1);
hold on;
xlim([phi(1) phi(end)]);
ylim([min_dB max_dB]);
set(gca, 'XTick', phi(1):45:phi(end));
grid on;
title(sprintf('\\theta-angle = %.0f deg', theta));
xlabel('\phi-angle [deg]');
if normalize
    ylabel('Relative gain [dB]');
else
    ylabel('Realized gain [dBi]');
end

end
