function h = plot_pod(H, dim, line_spec)
%PLOT_POD Plot PoD (probability of detection).
%
%   function h = plot_pod(H, dim, line_spec)
%
%   Plot PoD (probability of detection) curves from amplitude data in "H" along
%   dimension "dim" (default dimension maximum number of elements in "H") using
%   "line_spec" (default ''). A CCDF (complementary cumulative distribution
%   function) is generated from dimension "dim" of the amplitude data.
%
%   See also PLOT_CDF.

% By Ulf Carlberg.

if nargin<2 || isempty(dim), [~,dim] = max(size(H)); end
if nargin<3, line_spec = ''; end

P_av_dBt = sort(-20*log10(abs(H)), dim);
CCDF = (0:size(H,dim)-1)' / size(H,dim);

P_av_dBt = shiftdim(P_av_dBt, dim-1);

h = plot(P_av_dBt(:,:), CCDF, line_spec);
hold on;
grid on;
ylim([0 1]);
title('PoD - Probability of Detection');
xlabel('P_{av}/P_t [dBt]');
ylabel('Probability of Detection [-]');

end
