function h = plot_polar_farfield_phicut(a, ifreq, phi, plot_style)
%PLOT_POLAR_FARFIELD_PHICUT Polar plot for phi-cut of far-field.
%
%   function h = plot_polar_farfield_phicut(a, ifreq, phi, plot_style)
%
%   Plot phi-cut at angle "phi" (default 0) for far-field in antenna
%   structure "a" for frequency "ifreq" (default 1) using "plot_style"
%   default (''). The function plot_polar_format must be called before this
%   function.
%
%   See also PLOT_POLAR_FORMAT and PLOT_POLAR_FARFIELD_THETACUT. 

% By Ulf Carlberg.

if nargin<2 || isempty(ifreq), ifreq = 1; end
if nargin<3 || isempty(phi), phi = 0; end
if nargin<4, plot_style = ''; end

% Check so plot format is ok.
userdata = get(gcf, 'UserData');
if ~strcmpi(userdata.plot_type, 'phicut')
    error('Wrong plot format.');
end

text(-1.25, 1.20, sprintf('\\phi = %.0f^o', phi), 'FontSize', 10);

% Format data to plot.
k = 181;
theta = linspace(-180, 180, 2*k-1)';
phi1 = mod(phi-180, 360);
Eth_cut1 = interp2(a.phi, a.theta, a.Eth(:,:,ifreq), phi1, -theta(1:k-1), ...
    'linear', NaN);
Eph_cut1 = interp2(a.phi, a.theta, a.Eph(:,:,ifreq), phi1, -theta(1:k-1), ...
    'linear', NaN);
Eth_cut2 = interp2(a.phi, a.theta, a.Eth(:,:,ifreq), phi, theta(k:end), ...
    'linear', NaN);
Eph_cut2 = interp2(a.phi, a.theta, a.Eph(:,:,ifreq), phi, theta(k:end), ...
    'linear', NaN);
W_dB = 20*log10(hypot([Eth_cut1 ; Eth_cut2], [Eph_cut1 ; Eph_cut2]));

% Plot data.
h = plot_polar_data(90-theta, W_dB, plot_style);

end
