function h = plot_polar_farfield_thetacut(a, ifreq, theta, plot_style)
%PLOT_POLAR_FARFIELD_THETACUT Polar plot for theta-cut of far-field.
%
%   function h = plot_polar_farfield_thetacut(a, ifreq, theta, plot_style)
%
%   Plot theta-cut at angle "theta" (default 90) for far-field in antenna
%   structure "a" for frequency "ifreq" (default 1) using "plot_style"
%   default (''). The function plot_polar_format must be called before this
%   function.
%
%   See also PLOT_POLAR_FORMAT and PLOT_POLAR_FARFIELD_PHICUT. 

% By Ulf Carlberg.

if nargin<2 || isempty(ifreq), ifreq = 1; end
if nargin<3 || isempty(theta), theta = 90; end
if nargin<4, plot_style = ''; end

% Check so plot format is ok.
userdata = get(gcf, 'UserData');
if ~strcmpi(userdata.plot_type, 'thetacut')
    error('Wrong plot format.');
end

text(-1.25, 1.20, sprintf('\\theta = %.0f^o', theta), 'FontSize', 10);

% Format data to plot.
phi = linspace(0, 360, 361);
Eth_cut = interp2(a.phi, a.theta, a.Eth(:,:,ifreq), phi, theta, 'linear', NaN);
Eph_cut = interp2(a.phi, a.theta, a.Eph(:,:,ifreq), phi, theta, 'linear', NaN);
W_dB = 20*log10(hypot(Eth_cut, Eph_cut));

% Plot data.
h = plot_polar_data(phi, W_dB, plot_style);

end
