function h = plot_polarization_ellipse(a, theta, phi, plot_format)
%PLOT_POLARIZATION_ELLIPSE Plot polarization ellipse in time domain.
%
%   h = plot_polarization_ellipse(a, theta, phi, plot_format)
%
%   Plot polarization ellipse of antenna structure "a" for all frequencies in
%   direction given by "theta" and "phi" using "plot_format". Return the handle
%   "h" for the plot.

% By Ulf Carlberg.

if nargin<4, plot_format = 'b-'; end

% Take out far-field in specified direction.
Eth = zeros(a.Nfreq, 1);
Eph = zeros(a.Nfreq, 1);
for ifreq = 1:a.Nfreq
    Eth(ifreq) = interp2(a.phi, a.theta, a.Eth(:,:,ifreq), phi, theta);
    Eph(ifreq) = interp2(a.phi, a.theta, a.Eph(:,:,ifreq), phi, theta);
end

% Plot it in time domain.
t = exp(1j*linspace(0, 2*pi, 201));
h = plot(real(Eph*t)', -real(Eth*t)', plot_format, 'LineWidth', 1);
hold on;
axis equal;
grid on;
title('Polarization ellipse (time-domain)');
xlabel('\phi-hat direction');
ylabel('-\theta-hat direction');

end
