function data = read_ascii_file(filename, Nheaderlines)
%READ_ASCII_FILE Read ASCII file with float numbers
%
%   function data = read_ascii_file(filename, Nheaderlines)
%
%   Read file given by "filename", ignoring the first headlines given by
%   "Nheaderlines". Output a 2D matrix with numeric data.
%
%   This function has been optimized for speed.

% By Ulf Carlberg.

% Treat these characters as "whitespace" in the file.
whitespace = ' \b\t,;';

% Open file and find number of columns.
f = fopen(filename);
for ii = 1:Nheaderlines
    fgetl(f);  % ignore headerline
end
dataline1 = textscan(fgetl(f), '%f', 'Whitespace', whitespace);
Ncolumns = numel(dataline1{1});

% Read data and close file.
fseek(f, 0, 'bof');  % go back to beginning of file
rawdata = textscan(f, '%f', 'HeaderLines', Nheaderlines, ...
    'Whitespace', whitespace);
fclose(f);

% Provide data in 2D matrix.
data = reshape(rawdata{1}, Ncolumns, [])';

end
