function a = read_farfields_freq(filenames, freq)
%READ_FARFIELDS_FREQ Read several antenna far-fields from ASCII files.
%
%   function a = read_farfields_freq(filenames, freq)
%
%   Read far-field from several ASCII files, for different frequencies, and
%   output an antenna structure.

% By Ulf Carlberg.

if nargin<2, freq = []; end

% Convert a long string with newlines to cell array.
if ischar(filenames)
    filenames = strsplit(filenames, '\n');
end

% Read several data files for different frequencies.
for ifreq = 1:numel(filenames)
    if isempty(filenames{ifreq})
        continue;  % accept and ignore empty filenames
    end
    a_tmp = read_farfield(filenames{ifreq});
    if ifreq == 1
        a = a_tmp;
    else
        a.actions = cat(1, a.actions, a_tmp.actions);
        a.freq = cat(1, a.freq, a_tmp.freq);
        a.Nfreq = a.Nfreq + a_tmp.Nfreq;
        a.Eth = cat(3, a.Eth, a_tmp.Eth);
        a.Eph = cat(3, a.Eph, a_tmp.Eph);
    end
end
a.name = 'One data file for each frequency.';

% Change frequency vector?
if numel(freq) == 0
    % pass
elseif numel(freq) == 1
    a.freq = repmat(freq, a.Nfreq, 1);
elseif numel(freq) == a.Nfreq
    a.freq = freq(:);
else
    error('Wrong frequency argument.');
end

end
