function save_eps(filename, w_cm, h_cm, dpi)
%SAVE_EPS Save figure as a EPS file.
%
%   function save_eps(filename, w_cm, h_cm, dpi)
%
%   All arguments except the filename is optional. Default is to save an
%   (approximately) 12 cm x 9 cm image file with 300 dpi.

% By Ulf Carlberg.

% Default arguments.
if nargin<2 || isempty(w_cm), w_cm = 12; end
if nargin<3 || isempty(h_cm), h_cm = w_cm*9/12; end
if nargin<4 || isempty(dpi), dpi = 300; end

% Set figure size.
set(gcf, 'PaperUnits', 'centimeters');
set(gcf, 'PaperPosition', [(21-w_cm)/2 (29.7-h_cm)/2 w_cm h_cm]);

% Save to EPS.   
print(gcf, '-depsc2', ['-r' num2str(dpi)], filename);

end
