function save_png(filename, w_cm, h_cm, dpi)
%SAVE_PNG Save figure as a PNG file.
%
%   function save_png(filename, w_cm, h_cm, dpi)
%
%   All arguments except the filename is optional. Default is to save an
%   (approximately) 16 cm x 12 cm image file with 300 dpi.

% By Ulf Carlberg.

% Filename starts with star sign means don't plot!
if filename(1) == '*'; return; end

% Default arguments.
if nargin<2 || isempty(w_cm), w_cm = 16; end
if nargin<3 || isempty(h_cm), h_cm = w_cm*12/16; end
if nargin<4 || isempty(dpi), dpi = 300; end

% Set figure size.
set(gcf, 'PaperUnits', 'centimeters');
set(gcf, 'PaperPosition', [(21-w_cm)/2 (29.7-h_cm)/2 w_cm h_cm]);

% Matlab version R2014b or later?
if ~isoctave() && verLessThan('matlab', '8.4.0')
    warning(['Matlab version 2014b or later is recommended. Dashed and ' ...
        'dotted lines may look bad.']);
end

% Save to PNG.
print(gcf, '-dpng', ['-r' num2str(dpi)], filename);

end
