function a = translate_farfield(a, x, y, z)
%TRANSLATE_FARFIELD Translate antenna far-field structure.
%
%   function a = translate_farfield(a, x, y, z)
%
%   Translate antenna structure "a" far-field and output a new antenna
%   structure. This accounts for the phase-change introduced in different
%   directions, see Eq. (2.52) in [1].
%
%   If the phase reference point should be translated instead of the antenna,
%   change sign of input arguments "x", "y", and "z" when calling this function,
%   see Eq. (2.51) in [1].
%
%   References:
%   [1] "Foundations of Antennas - A Unified Approach" by Per-Simon Kildal,
%       2000 Studentlitteratur.

% By Ulf Carlberg.

% Leave tag on structure.
a.actions{end+1,1} = ['translate_farfield(*, ' function_call_str({x, y, z}) ...
    ')'];

% Far-field vectors.
[theta2D, phi2D] = ndgrid(a.theta, a.phi);
[urx, ury, urz] = unit_vector_r(theta2D, phi2D);

% Change phase of antenna.
k = 2*pi*a.freq/c0;
k(k<0) = 2*pi;
for ifreq = 1:a.Nfreq
    phase_change = exp(1j*(urx*x+ury*y+urz*z)*k(ifreq));  % Eq. (2.52) in [1]
    a.Eth(:,:,ifreq) = a.Eth(:,:,ifreq) .* phase_change;
    a.Eph(:,:,ifreq) = a.Eph(:,:,ifreq) .* phase_change;
end

end
