function [x, y, z] = unit_vector_r(theta, phi, avoid_poles)
%UNIT_VECTOR_R Cartesian-coordinates (xyz-coordinates) of the spherical unit vector r-hat for angles theta and phi.
%
%   function [x, y, z] = unit_vector_r(theta, phi, avoid_poles)
%
%   Return the xyz-coordinates of the spherical unit vector r-hat for the
%   angles "theta" and "phi". "theta" is the angle from the z-axis and "phi" is
%   the azimuth angle from the x-axis in the xy-plane.
%
%   See also UNIT_VECTOR_THETA and UNIT_VECTOR_PHI.

% By Ulf Carlberg.

if nargin<3, avoid_poles = 0; end

% Avoid being exactly on north pole or south pole?
sin_th = sind(theta);
if avoid_poles > 0
    sin_th(sin_th==0) = eps;
elseif avoid_poles < 0
    sin_th(sin_th==0) = -eps;
end

x = sin_th .* cosd(phi);
y = sin_th .* sind(phi);
z = cosd(theta);

end
