function y = xmat(x, new_size)
%XMAT Expand a matrix to a new size defined by the user.
%
%   function y = xmat(x, new_size)
%
%   Expand matrix "x" to "y". "y" will get the size "new_size".
%
%   Example:
%   If a = [8 1 6
%           3 5 7
%           4 9 2]
%   then xmat(a, [4 5]) is [8 1 6 8 1
%                           3 5 7 3 5
%                           4 9 2 4 9
%                           8 1 6 8 1].
%
%   See also REPMAT.

% By Ulf Carlberg.

old_size = size(x);

% Make sure size vectors have equal lengths.
N = max(length(new_size), length(old_size));
old_size = [old_size ones(1, N-length(old_size))];
new_size = [new_size ones(1, N-length(new_size))];

% Expand matrix.
y = repmat(x, ceil(new_size./old_size));

% Pick out submatrix (if needed).
if any(mod(new_size, old_size))
    subs = cell(1, length(new_size));
    for ii = 1:length(new_size)
        subs{ii} = 1:new_size(ii);
    end
    y = y(subs{:});
end

end
