function [r, theta, phi] = xyz2rthetaphi(x, y, z)
%XYZ2RTHETAPHI Convert cartesian (xyz) coordinates to spherical coordinates (using degrees).
%
%   function [r, theta, phi] = xyz2rthetaphi(x, y, z)
%
%   Convert xyz-coordinates to spherical coordinates "r", "theta", and "phi".
%   "theta" is the angle (in degrees) from the z-axis, and is always in the
%   interval [0..180]. "phi" is the azimuth angle (in degrees) from the x-axis
%   in the xy-plane and is always in the interval [0..360].
%
%   See also RTHETAPHI2XYZ.

% By Ulf Carlberg.

rho = hypot(x, y);
r = hypot(rho, z);
theta = atan2d(rho, z);
phi = mod(atan2d(y,x), 360);

end
