function x_zc = zero_crossings(x, y, crossing_type)
%ZERO_CROSSINGS Find zero crossings.
%
%   function x_zc = zero_crossings(x, y, crossing_type)
%
%   Find zero crossings of data "y" for x-values "x". Both inputs must be column
%   vectors with the same number of elements. "crossing_type" can be 'any'
%   (default), 'neg2pos', or 'pos2neg'. Zero-values of "y" are considered
%   positive in this implementation.

% By Ulf Carlberg.

if nargin<3, crossing_type = 'any'; end

% Check input.
N = numel(x);
assert(max(size(x))==N, 'Input x must be one-dimensional.');
assert(numel(y)==N, 'Input y must have the same number of elements as x.');
assert(max(size(y))==N, 'Input y must be one-dimensional.');

% Find index of zero-crossings.
if strcmpi(crossing_type, 'any')
    ix = find(abs(diff(y>=0)) == 1);
elseif strcmpi(crossing_type, 'neg2pos')
    ix = find(diff(y>=0) == 1);
elseif strcmpi(crossing_type, 'pos2neg')
    ix = find(diff(y>=0) == -1);
else
    error('Unknown crossing type.');
end

% Return x-values of zero-crossings.
x_zc = x(ix) + y(ix) .* (x(ix+1)-x(ix)) ./ (y(ix)-y(ix+1));

end
