% Clear and calculate.
close all;
clear;
clc;

fprintf('Rotation of dipoles, linear phase:\n');
a = gen_farfield('inc. electric dipole');
figure;
for theta = 0:45:90
    p_rx = gen_positions(0,-5,0,0,theta,0);
    p_tx = gen_positions(0,5,0,0,theta,0);

    plot_farfield_inpos(a, p_rx);
    plot_farfield_inpos(a, p_tx);

    H = calc_coupling(a, p_rx, a, p_tx);
    fprintf('  H = %6.1f dB, phase %6.1f deg.\n', 20*log10(abs(H)), ...
        angle(H)*180/pi);
end

fprintf('\nHuygens sources RHC->RHC:\n');
a = gen_farfield('inc. Huygens source RHC');
for alpha = 0:45:90
    p_rx = gen_positions(0,-5,0,alpha,90,90);
    p_tx = gen_positions(0,5,0,-alpha,90,-90);
    
    H = calc_coupling(a, p_rx, a, p_tx);
    fprintf('  H = %6.1f dB, phase %6.1f deg.\n', 20*log10(abs(H)), ...
        angle(H)*180/pi);
end
figure;
plot_farfield_inpos(a, p_rx);
plot_farfield_inpos(a, p_rx);

fprintf('\nHuygens sources LHC->RHC:\n');
a_rx = gen_farfield('inc. Huygens source RHC');
a_tx = gen_farfield('inc. Huygens source LHC');
for alpha = 0:45:90
    p_rx = gen_positions(0,-5,0,alpha,90,90);
    p_tx = gen_positions(0,5,0,-alpha,90,-90);

    H = calc_coupling(a_rx, p_rx, a_tx, p_tx);
    fprintf('  H = %6.1f dB, phase %6.1f deg.\n', 20*log10(abs(H)), ...
        angle(H)*180/pi);
end

fprintf('\nHuygens sources RHC->LIN:\n');
a_rx = gen_farfield('inc. Huygens source');
a_tx = gen_farfield('inc. Huygens source RHC');
for alpha = 0:45:90
    p_rx = gen_positions(0,-5,0,alpha,90,90);
    p_tx = gen_positions(0,5,0,-alpha,90,-90);

    H = calc_coupling(a_rx, p_rx, a_tx, p_tx);
    fprintf('  H = %6.1f dB, phase %6.1f deg.\n', 20*log10(abs(H)), ...
        angle(H)*180/pi);
end

fprintf('\nMeasured pattern with many frequencies:\n');
a_rx = read_farfield('../data/Laird/top_antenna_single_hand.txt');
a_tx = a_rx;
p_rx = gen_positions(0, -1, 0, 0, 0, 0);
p_tx = gen_positions(0, 1, 0, 180, 0, 0);
H = calc_coupling(a_rx, p_rx, a_tx, p_tx);
for ii = [1 numel(H)]
    fprintf('  f = %.3f GHz, H = %6.1f dB, phase %6.1f deg.\n', ...
        a_rx.freq(ii)/1e9, 20*log10(abs(H(ii))), angle(H(ii))*180/pi);
end
figure;
plot_farfield_inpos(a_rx, p_rx);
plot_farfield_inpos(a_tx, p_tx);
