close all;
clear;

a = gen_farfield('inc. electric dipole');
a_tmp = rotate_farfield(a, 0, 90, 0);
a.Eth = a.Eth + 1j * a_tmp.Eth;
a.Eph = a.Eph + 1j * a_tmp.Eph;

phi = (-180:2:180)';
theta = (0:2:180)';

AR_dB = get_ar(a, theta, phi);
XPD_dB = get_xpd(a, [1 1j], theta, phi);

% Check formula in AR calculation.
[Eth, Eph] = get_farfield_components(a, theta, phi);
t = linspace(0, pi, 4001);
Emin = +inf(size(Eth));
Emax = -inf(size(Eth));
for ii = 1:numel(t)
    E = hypot(real(Eph*exp(1j*t(ii))), real(Eth*exp(1j*t(ii))));
    Emin = min(Emin, E);
    Emax = max(Emax, E);
end
AR_check_dB = 20*log10(Emax./Emin);
AR_check_dB = min(AR_check_dB, 300);
error_dB = AR_check_dB - AR_dB;
error_dB(AR_check_dB>40 & AR_dB>40) = 0;
max(abs(error_dB(:)))

figure;
surf(phi, theta, AR_dB);
colormap(jet(256));
caxis([0 30]);
colorbar;
view(0, 90);
shading interp;
axis image;
set(gca, 'XTick', phi(1):45:phi(end));
set(gca, 'YTick', theta(1):45:theta(end));
set(gca, 'YDir', 'reverse');
set(gca, 'TickDir', 'out');
box on;
title('Axial Ratio [dB]');
xlabel('\phi-angle [deg]');
ylabel('\theta-angle [deg]');

figure;
surf(phi, theta, XPD_dB);
colormap(jet(256));
caxis([-30 30]);
colorbar;
view(0, 90);
shading interp;
axis image;
set(gca, 'XTick', phi(1):45:phi(end));
set(gca, 'YTick', theta(1):45:theta(end));
set(gca, 'YDir', 'reverse');
set(gca, 'TickDir', 'out');
box on;
title('Cross-polar decoupling [dB]');
xlabel('\phi-angle [deg]');
ylabel('\theta-angle [deg]');
