% Test generation of far-field functions for canonical antennas.
close all;
clear;

% Generate some farfield.
a = gen_farfield('cosn 45', 41, 81);
plot_farfield(a);

% Avoid Octave bug?
octave_bug_work_around = isoctave();

% Test rotations.
N = 100;
alpha = 360*rand(N,1);
theta = 180*rand(N,1);
phi = 360*rand(N,1);
error_dB = zeros(N,1);
th = 180*rand(N+1,1);
ph = 360*rand(N+1,1);
for ii = 1:N

    % Explicit rotation.
    a2 = rotate_farfield(a, alpha(ii), theta(ii), phi(ii));
    if octave_bug_work_around
        indx = ii:ii+1;
    else
        indx = ii;
    end
    Eth1 = interp2(a2.phi, a2.theta, a2.Eth, ph(indx), th(indx), 'linear', NaN);
    Eph1 = interp2(a2.phi, a2.theta, a2.Eph, ph(indx), th(indx), 'linear', NaN);
    if octave_bug_work_around
        Eth1 = Eth1(1);
        Eph1 = Eph1(1);
    end

    % Implicit rotation.
    [Eth2, Eph2] = get_farfield(a, alpha(ii), theta(ii), phi(ii), ...
        th(ii), ph(ii));
    
    % Numerical error vector.
    tmp = 10*log10(abs(Eth1-Eth2).^2+abs(Eph1-Eph2).^2);
    error_dB(ii) = tmp(1);
end
assert(~any(isnan(error_dB)), 'Got an unexpected NaN');
fprintf('Max numerical error = %.2f dB.\n', max(error_dB));
